pomop - Poor man Pomodoro
=========================

Simple CLI app for run a pomodoro.

.. image:: https://travis-ci.org/hvnsweeting/pomop.svg?branch=master
    :target: https://travis-ci.org/hvnsweeting/pomop

Installation
------------

By using pip::

    pip install pomop

Usage
-----

Just run `pomop 'fix bug xyz'` for a 25 minutes pomodoro, it will notify when time-up.

Options
-------

-l LENGTH, --length LENGTH
					Length in minutes of this pomodoro
-S, --nosound         Turn off sound notification
-B, --nobrowser       Turn off browser-open notification

Features
--------

- Supports both Python2 and Python3
- No 3rd dependency
- Run on Linux, OSX, Windows

Roadmaps
--------

- Supports send notifications on OSX & Windows

Authors
-------

Viet Hung Nguyen <hvn@familug.org>
- Support both Python2 and Python3
